@@ -44,13 +44,13 @@ Examples:
     >>> config.var = 665
     >>> config.var
     665
-    >>> config.var = "String is problem"
+    >>> config.var = "String is problem"  # doctest: +IGNORE_EXCEPTION_DETAIL
     Traceback (most recent call last):
     TypeError: ...
     ...
-    >>> config.var_literal = 4
+    >>> config.var_literal = 4  # doctest: +IGNORE_EXCEPTION_DETAIL
     Traceback (most recent call last):
-    KeyError: ...
+    TypeError: ...
     ...
     >>> config.evaluated
     666
@@ -60,46 +60,31 @@ Examples:
     >>> config.var = lambda self: self.var_literal + 1
 
 """
-
 from __future__ import annotations
-from typing import get_type_hints, Union
 
-from typing_extensions import Literal
+from typing import Generic, TypeVar, Callable, Type, overload, Any
 
-from .misc import validate
+from typeguard import check_type
+
+from . import type_hints
 
 
-class MyProperty:
+T = TypeVar("T")
+U = TypeVar("U")
+
+
+class MyPropertyClass(Generic[T]):
     """Python property on steroids. Check module docstrings for more info."""
 
-    def __init__(self, fget=None, fset=None, fdel=None, doc=None):
+    def __init__(self, fget: Callable[..., T] = None, fset: Callable = None, fdel=None, doc=None):
 
-        # Validation
-        return_type_str = fget.__annotations__.get("return")
+        if fget:
+            self.allowed_types = type_hints.get_return_type_hints(fget)
 
-        # If Union operator | defined with string - Postponed Evaluation, separate and create normal Union
-        # Because get_type_hints() result in TypeError if for example int | str
-        if return_type_str and "|" in return_type_str:
-            all_union_types = [eval(i) for i in return_type_str.split("|")]
-            self.types = Union[all_union_types[0], all_union_types[1]]
+            self.init_function = fget
 
-            if len(all_union_types) > 2:
-                for i in all_union_types[2:]:
-                    self.types = Union[self.types, i]
-
-        else:
-            self.types = get_type_hints(fget).get("return")
-
-        # If Literal - parse options
-        if hasattr(self.types, "__origin__") and getattr(self.types, "__origin__") == Literal:
-            self.options = getattr(self.types, "__args__")
-            self.types = None
-        else:
-            self.options = None
-        self.init_function = fget
-
-        if fget.__doc__:
-            self.__doc__ = self.__doc__
+            if fget.__doc__:
+                self.__doc__ = self.__doc__
 
     def default_fset(self, object, content) -> None:
         setattr(object, self.private_name, content)
@@ -108,8 +93,15 @@ class MyProperty:
         self.public_name = name
         self.private_name = "_" + name
 
+    @overload
+    def __get__(self, object: None, objtype: Any = None) -> MyPropertyClass[T]:
+        ...
+
+    @overload
+    def __get__(self, object: U, objtype: Type[U] = None) -> T:
+        ...
+
     def __get__(self, object, objtype=None):
-        # If getting MyProperty class, not object, return MyProperty itself
         if not object:
             return self
 
@@ -125,7 +117,7 @@ class MyProperty:
 
         return value
 
-    def __set__(self, object, content):
+    def __set__(self, object, content: T | Callable[..., T]):
 
         # You can setup value or function, that return that value
         if callable(content):
@@ -133,18 +125,9 @@ class MyProperty:
         else:
             result = content
 
-        validate(
-            result,
-            self.types,
-            self.options,
-            self.public_name,
-        )
+        check_type(expected_type=self.allowed_types, value=result, argname=self.public_name)
 
-        # Method defined can be pass as static method
-        try:
-            self.default_fset(object, content)
-        except TypeError:
-            self.default_fset(self, object, content)
+        self.default_fset(object, result)
 
 
 def init_my_properties(self):
@@ -152,7 +135,7 @@ def init_my_properties(self):
         setattr(self, "myproperties_list", [])
 
     for i, j in vars(type(self)).items():
-        if type(j) is MyProperty:
+        if type(j) is MyPropertyClass:
             self.myproperties_list.append(j.public_name)
             setattr(
                 self,
@@ -161,48 +144,38 @@ def init_my_properties(self):
             )
 
 
-from typing_extensions import Literal
+def MyProperty(f: Callable[..., T]) -> MyPropertyClass[T]:
+    """The reason for function workaraund is that it's more clear in IDE help, that
+    used attribute is not value, but is result of descriptor __get__ and __set__ functions
+    as type in help is not just MyProperty, but () -> USED_TYPE."""
+    return MyPropertyClass[T](f)
 
 
-if __name__ == "__main__":
+# TODO - Use PEP 614 and define type just in class decorator
+# Python 3.9 necessary
 
-    class Example:
-        def __init__(self) -> None:
-            init_my_properties(self)
+# if __name__ == "__main__":
 
-        @MyProperty
-        def var() -> int:  # Type hints are validated.
-            """
-            Type:
-                int
+#     from typing_extensions import Literal
 
-            Default:
-                123
+#     class Example:
+#         def __init__(self) -> None:
+#             init_my_properties(self)
 
-            This is docstrings (also visible in IDE, because not defined dynamically).
-            Also visible in Sphinx documentation."""
+#         @MyProperty
+#         def var_literal(self) -> Literal["asd", "rbrb"]:  # Literal options are also validated
+#             return "asd"
 
-            return 123  # This is initial value that can be edited.
+#     a = Example.var_literal
+#     example = Example()
 
-        @MyProperty
-        def var_literal(self) -> Literal[1, 2, 3]:  # Literal options are also validated
-            return 2
+#     a = example.var_literal  # In VS Code help str instead of Literal
 
-        @MyProperty
-        def evaluated(self) -> int:  # If other defined value is change, computed property is also updated
-            return self.var + 1
+#     example.var_literal = "asd"  # Correct
+#     example.var_literal = "asdasd"  # This should not work
+#     example.var_literal = 1  # If int, it's correct
 
-    config = Example()
-    config.var
+#     def withf() -> Literal["efe"]:
+#         return "efe"
 
-    def aj(self):
-        return
-
-    config.var = lambda self: self.var_literal + 1
-    config.var
-
-    config.var = "String is problem"
-
-    config.var_literal = 4
-
-    config.evaluated
+#     example.var_literal = withf  # This is the same ... () -> str instead of str () -> Literal[]
